@@ -6,7 +6,7 @@
 # GitHub:  https://github.com/szczyglis-dev/py-gpt   #
 # MIT License                                        #
 # Created By  : Marcin Szczygliński                  #
-# Updated Date: 2024.11.21 20:00:00                  #
+# Updated Date: 2025.08.03 14:00:00                  #
 # ================================================== #
 
 from .common import Common
@@ -17,7 +17,7 @@ from .llama import Llama
 class Agent:
     def __init__(self, window=None):
         """
-        Agent controller
+        Agents controller
 
         :param window: Window instance
         """
