@@ -6,7 +6,7 @@
 # GitHub:  https://github.com/szczyglis-dev/py-gpt   #
 # MIT License                                        #
 # Created By  : Marcin Szczygliński                  #
-# Updated Date: 2025.07.25 17:00:00                  #
+# Updated Date: 2025.08.11 14:00:00                  #
 # ================================================== #
 
 import json
@@ -62,6 +62,8 @@ class Threads(QObject):
         ctx.from_previous()  # append previous result if exists
         self.window.core.ctx.update_item(ctx)
         self.window.controller.chat.output.handle(ctx, 'assistant', stream)
+        if ctx.meta and not ctx.meta.initialized:
+            self.window.controller.ctx.summarizer.summarize(ctx.meta.id, ctx)
         if stream:
             return  # handled in: self.handle_output_message_after_stream() after stream:handleEvent
 
@@ -614,7 +616,7 @@ class RunSignals(QObject):
 class RunWorker(QRunnable):
     """Status check async worker"""
     def __init__(self, *args, **kwargs):
-        super(RunWorker, self).__init__()
+        super().__init__()
         self.signals = RunSignals()
         self.args = args
         self.kwargs = kwargs
@@ -659,7 +661,21 @@ class RunWorker(QRunnable):
 
             if self.signals.destroyed is not None:
                 self.signals.destroyed.emit()
+
         except Exception as e:
             self.window.core.debug.log(e)
             if self.signals.destroyed is not None:
                 self.signals.destroyed.emit()
+
+        finally:
+            self.cleanup()
+
+    def cleanup(self):
+        """Cleanup resources after worker execution."""
+        sig = self.signals
+        self.signals = None
+        if sig is not None:
+            try:
+                sig.deleteLater()
+            except RuntimeError:
+                pass
