@@ -6,7 +6,7 @@
 # GitHub:  https://github.com/szczyglis-dev/py-gpt   #
 # MIT License                                        #
 # Created By  : Marcin Szczygliński                  #
-# Updated Date: 2025.07.16 15:00:00                  #
+# Updated Date: 2025.08.06 01:00:00                  #
 # ================================================== #
 import os
 from typing import Optional, List
@@ -149,9 +149,6 @@ class Image:
             string += "[{}]({})".format(basename, path) + "\n"
             i += 1
 
-        if self.window.core.config.get('img_dialog_open'):
-            self.window.tools.get("viewer").open_images(paths)  # use viewer tool
-
         if not self.window.core.config.get('img_raw'):
             string += "\nPrompt: "
             string += prompt
