@@ -6,7 +6,7 @@
 # GitHub:  https://github.com/szczyglis-dev/py-gpt   #
 # MIT License                                        #
 # Created By  : Marcin Szczygliński                  #
-# Updated Date: 2025.07.21 19:00:00                  #
+# Updated Date: 2025.08.11 00:00:00                  #
 # ================================================== #
 
 from typing import Any, Optional
@@ -19,6 +19,7 @@ from pygpt_net.core.types import (
 )
 from pygpt_net.core.events import Event, AppEvent, RenderEvent, KernelEvent
 from pygpt_net.item.ctx import CtxItem
+from pygpt_net.utils import mem_clean
 
 
 class Output:
@@ -225,7 +226,7 @@ class Output:
                 self.window.controller.chat.common.unlock_input()  # unlock input
 
         # handle ctx name (generate title from summary if not initialized)
-        if not reply and not internal:  # don't call if reply or internal mode
+        if not ctx.meta or not ctx.meta.initialized:  # don't call if reply or internal mode
             if self.window.core.config.get('ctx.auto_summary'):
                 self.log("Calling for prepare context name...")
                 self.window.controller.ctx.prepare_name(ctx)  # async
@@ -293,6 +294,10 @@ class Output:
             event = RenderEvent(RenderEvent.RELOAD)
             self.window.dispatch(event)  # reload chat window
 
+        mem_clean()
+
+        # self.window.core.debug.mem("END")  # debug memory usage
+
     def log(self, data: Any):
         """
         Log data to debug
