@@ -6,7 +6,7 @@
 # GitHub:  https://github.com/szczyglis-dev/py-gpt   #
 # MIT License                                        #
 # Created By  : Marcin Szczygliński                  #
-# Updated Date: 2025.08.01 19:00:00                  #
+# Updated Date: 2025.08.12 19:00:00                  #
 # ================================================== #
 
 from typing import Optional, List
@@ -15,14 +15,13 @@ from PySide6.QtCore import QModelIndex, QTimer
 from PySide6.QtGui import QStandardItem
 
 from pygpt_net.core.events import Event, AppEvent, RenderEvent
-from pygpt_net.item.ctx import CtxItem
+from pygpt_net.item.ctx import CtxItem, CtxMeta
 
 from .common import Common
 from .summarizer import Summarizer
 from .extra import Extra
 
 from pygpt_net.utils import trans
-from pygpt_net.core.tabs.tab import Tab
 
 
 class Ctx:
@@ -173,6 +172,7 @@ class Ctx:
         # update additional context attachments
         self.window.controller.chat.attachment.update()
         self.set_selected(id)
+        self.clean_memory()  # clean memory
 
     def select_on_list_only(self, id: int):
         """
@@ -252,6 +252,10 @@ class Ctx:
         self.group_id = None
         self.new()
 
+    def clean_memory(self):
+        """Clean memory"""
+        self.window.core.gpt.close()  # clear gpt client
+
     def new(
             self,
             force: bool = False,
@@ -283,12 +287,7 @@ class Ctx:
         self.window.core.config.set('assistant_thread', None)  # reset assistant thread id
         self.update()
 
-        # render reset
-        data = {
-            "meta": meta,
-        }
-        event = RenderEvent(RenderEvent.CLEAR, data)
-        self.window.dispatch(event)
+        self.fresh_output(meta)  # render reset
 
         if not force:  # only if real click on new context button
             self.window.controller.chat.common.unlock_input()
@@ -313,6 +312,8 @@ class Ctx:
 
         # switch to new context if non-chat tab
         self.select(meta.id)
+
+        # self.window.core.debug.mem("NEW")  # debug memory usage
         return meta
 
     def add(self, ctx: CtxItem):
@@ -405,11 +406,7 @@ class Ctx:
 
         # reset appended data / prepare new ctx
         if meta is not None:
-            data = {
-                "meta": meta,
-            }
-            event = RenderEvent(RenderEvent.ON_LOAD, data)
-            self.window.dispatch(event)
+            self.fresh_output(meta)  # render reset
 
         self.reload_config()
 
@@ -950,11 +947,12 @@ class Ctx:
         :param child_id: int
         :return: QModelIndex
         """
+        finder = self.find_child_index_by_id
         for row in range(root_item.rowCount()):
             item = root_item.child(row)
             if hasattr(item, 'id') and hasattr(item, 'isFolder') and not item.isFolder and item.id == child_id:
                 return item.index()
-            child_index = self.find_child_index_by_id(item, child_id)
+            child_index = finder(item, child_id)
             if child_index.isValid():
                 return child_index
         return QModelIndex()
@@ -1237,3 +1235,22 @@ class Ctx:
     def clear_selected(self):
         """Clear selected list"""
         self.selected = []
+
+
+    def fresh_output(self, meta: CtxMeta):
+        """
+        Fresh output for new context
+
+        :param meta: CtxItem
+        """
+        # render reset
+        data = {
+            "meta": meta,
+        }
+        event = RenderEvent(RenderEvent.FRESH, data)
+        self.window.dispatch(event)
+        data = {
+            "meta": meta,
+        }
+        event = RenderEvent(RenderEvent.ON_LOAD, data)
+        self.window.dispatch(event)
