@@ -6,10 +6,10 @@
 # GitHub:  https://github.com/szczyglis-dev/py-gpt   #
 # MIT License                                        #
 # Created By  : Marcin Szczygliński                  #
-# Updated Date: 2025.07.20 23:00:00                  #
+# Updated Date: 2025.08.08 23:00:00                  #
 # ================================================== #
 
-from typing import Any, Optional
+from typing import Any, Optional, Tuple
 
 from PySide6.QtCore import QTimer
 
@@ -139,13 +139,15 @@ class Tabs:
     def reload_after(self):
         """Reload tabs after"""
         for pid in self.window.ui.nodes['output']:
-            if self.window.core.config.get("render.plain") is True:
-                self.window.ui.nodes['output_plain'][pid].setVisible(True)
-                self.window.ui.nodes['output'][pid].setVisible(False)
-            else:
-                self.window.ui.nodes['output_plain'][pid].setVisible(False)
-                self.window.ui.nodes['output'][pid].setVisible(True)
-        #self.switch_tab(Tab.TAB_CHAT)
+            try:
+                if self.window.core.config.get("render.plain") is True:
+                    self.window.ui.nodes['output_plain'][pid].setVisible(True)
+                    self.window.ui.nodes['output'][pid].setVisible(False)
+                else:
+                    self.window.ui.nodes['output_plain'][pid].setVisible(False)
+                    self.window.ui.nodes['output'][pid].setVisible(True)
+            except Exception as e:
+                pass
         self.debug()
 
     def on_tab_changed(
@@ -176,6 +178,7 @@ class Tabs:
 
         prev_tab = self.current
         prev_column = self.column_idx
+
         self.current = idx
         self.column_idx = column_idx
         self.window.controller.ui.mode.update()
@@ -285,6 +288,38 @@ class Tabs:
         """
         return self.window.core.tabs.get_min_idx_by_type(type, self.column_idx)
 
+    def get_prev_idx_from(self, idx: int) -> Tuple[int, bool]:
+        """
+        Get previous tab index from given index
+
+        :param idx: tab index
+        :return: tuple of previous index and boolean indicating if it exists
+        """
+        return self.window.core.tabs.get_prev_idx_from(idx, self.column_idx)
+
+    def get_next_idx_from(self, idx: int) -> Tuple[int, bool]:
+        """
+        Get next tab index from given index
+
+        :param idx: tab index
+        :return: tuple of next index and boolean indicating if it exists
+        """
+        return self.window.core.tabs.get_next_idx_from(idx, self.column_idx)
+
+    def get_after_close_idx(self, idx: int) -> int:
+        """
+        Get tab index after closing the given index
+
+        :param idx: tab index
+        :return: previous tab index if exists, otherwise None
+        """
+        prev_idx, exists = self.get_prev_idx_from(idx)
+        if exists:
+            return prev_idx
+        next_idx, exists = self.get_next_idx_from(idx)
+        if exists:
+            return next_idx
+
     def on_column_changed(self):
         """Column changed event"""
         if self.locked:
@@ -302,6 +337,14 @@ class Tabs:
         tab = self.window.core.tabs.get_tab_by_index(self.current, self.column_idx)
         if tab is None:
             return
+
+        # redraw second tab if not loaded yet
+        if tab.type == Tab.TAB_CHAT and self.column_idx == 1 and not tab.loaded:
+            meta = self.window.core.ctx.get_meta_by_id(tab.data_id)
+            if meta is not None:
+                self.window.controller.ctx.load(meta.id)
+            tab.loaded = True
+
         current_ctx = self.window.core.ctx.get_current()
         if (current_ctx is not None and current_ctx != tab.data_id) or current_ctx is None:
             if tab.type == Tab.TAB_CHAT:
@@ -371,7 +414,21 @@ class Tabs:
         """
         if self.locked:
             return
+
+        previous_current = self.current
+        idx_after = None  # <--- next tab index after close to switch to
+        if previous_current != idx and self.column_idx == column_idx:
+            idx_after = previous_current
+            if idx_after > idx:
+                idx_after -= 1  # if current is after closed tab, idx will be shifted
+
+        if idx_after is None:
+            idx_after = self.get_after_close_idx(idx)  # find next tab index after close
+
         self.window.core.tabs.remove_tab_by_idx(idx, column_idx)
+        if idx_after is not None:
+            self.switch_tab_by_idx(idx_after, column_idx)
+
         self.on_changed()
         self.update_current()
         self.debug()
@@ -557,7 +614,7 @@ class Tabs:
         :param name: new title
         :param close: close dialog
         """
-        self.window.core.tabs.update_title(idx, name)
+        self.window.core.tabs.update_title(idx, name, name)
         if close:
             self.window.ui.dialog['rename'].close()
         self.debug()
@@ -629,7 +686,10 @@ class Tabs:
 
         :param column_idx: column index
         """
-        idx = self.get_current_idx(column_idx)
+        # append at the end of column
+        idx = self.window.core.tabs.get_max_idx_by_column(column_idx)
+        if idx == -1:
+            idx = 0
         self.append(
             type=Tab.TAB_CHAT,
             tool_id=None,
@@ -801,52 +861,70 @@ class Tabs:
         :param title: new tab name (optional, for chat tab)
         :param meta: context meta (optional, for chat tab)
         """
-        # first try to focus current tab
+        # try to focus tab
         if self.get_current_type() != type:
-            # first, check in second column
-            second_column_idx = 1 if self.column_idx == 0 else 0
-            # get current tab from second column
-            tabs = self.window.ui.layout.get_tabs_by_idx(second_column_idx)
-            second_tabs_idx = tabs.currentIndex()
-            second_tab = self.window.core.tabs.get_tab_by_index(second_tabs_idx, second_column_idx)
-            if second_tab is not None and second_tab.type == type:
-                # switch to second column
-                self.on_column_focus(second_column_idx)
-                tabs.setCurrentIndex(second_tabs_idx)
-                if meta:
-                    QTimer.singleShot(100, lambda: self.window.controller.ctx.load(meta.id))
-                self.debug()
-                return
 
-            idx, column_idx, exists = self.window.core.tabs.get_min_idx_by_type_exists(type)
+            # find the closest tab in current column (on left side)
+            current = self.get_current_tab()
+            exists = False
+            if current:
+                idx, column_idx, exists = self.window.core.tabs.get_closest_idx_by_type_exists(
+                    current,
+                    type,
+                    self.column_idx
+                )
             if exists:
-                tabs = self.window.ui.layout.get_tabs_by_idx(column_idx)
-                if tabs and idx:
-                    tabs.setCurrentIndex(idx)
-                    self.debug()
-                    return
+                tab = self.window.core.tabs.get_tab_by_index(idx, column_idx)
             else:
-                # if current is not type, find first tab
+                # if not exists in current col, then find first idx in any column
                 tab = self.window.core.tabs.get_first_by_type(type)
-                if tab:
-                    tabs = self.window.ui.layout.get_tabs_by_idx(tab.column_idx)
-                    if tabs:
-                        idx = tab.idx
-                        if data_id is not None:
-                            tab.data_id = data_id
-                            if title is not None:
-                                self.update_title_current(title)
-                        else:
-                            self.on_column_focus(tab.column_idx)
-                        if meta is not None:
-                            self.on_column_focus(tab.column_idx)
-                            self.window.controller.ctx.load(meta.id)
-                            QTimer.singleShot(100, lambda: self.window.controller.ctx.load(meta.id))
-                            self.on_column_focus(tab.column_idx)
-                        tabs.setCurrentIndex(idx)
+
+            if tab:
+                # if tab is found in current column, switch to it
+                tabs = self.window.ui.layout.get_tabs_by_idx(tab.column_idx)
+                if tabs:
+                    idx = tab.idx
+                    if data_id is not None:
+                        tab.data_id = data_id
+                        if title is not None:
+                            self.update_title_current(title)
+                    else:
+                        self.on_column_focus(tab.column_idx)
+                    if meta is not None:
+                        self.on_column_focus(tab.column_idx)
+                        self.window.controller.ctx.load(meta.id)
+                        QTimer.singleShot(100, lambda: self.window.controller.ctx.load(meta.id))
+                        self.on_column_focus(tab.column_idx)
+                    tabs.setCurrentIndex(idx)
+            else:
+                # if not found in current column, then check in second column
+                second_column_idx = 1 if self.column_idx == 0 else 0
+                # get current tab from second column
+                tabs = self.window.ui.layout.get_tabs_by_idx(second_column_idx)
+                second_tabs_idx = tabs.currentIndex()
+                second_tab = self.window.core.tabs.get_tab_by_index(second_tabs_idx, second_column_idx)
+                if second_tab is not None and second_tab.type == type:
+                    # switch to second column
+                    self.on_column_focus(second_column_idx)
+                    tabs.setCurrentIndex(second_tabs_idx)
+                    if meta:
+                        QTimer.singleShot(100, lambda: self.window.controller.ctx.load(meta.id))
+
+            # if second and split screen disabled, then enable it
+            if tab and tab.column_idx == 1:
+                if not self.is_split_screen_enabled():
+                    self.enable_split_screen(update_switch=True)
 
         self.debug()
 
+    def is_split_screen_enabled(self) -> bool:
+        """
+        Check if split screen mode is enabled
+
+        :return: True if split screen is enabled, False otherwise
+        """
+        return self.window.core.config.get("layout.split", False)
+
 
     def on_split_screen_changed(self, state: bool):
         """
@@ -854,7 +932,7 @@ class Tabs:
 
         :param state: True if split screen is enabled
         """
-        prev_state = self.window.core.config.get("layout.split", False)
+        prev_state = self.is_split_screen_enabled()
         self.window.core.config.set("layout.split", state)
         if prev_state != state:
             if self.window.ui.nodes['layout.split'].box.isChecked() != state:
@@ -867,7 +945,7 @@ class Tabs:
 
         :param update_switch: True if switch should be updated
         """
-        if self.window.core.config.get("layout.split", False):
+        if self.is_split_screen_enabled():
             return
 
         self.window.ui.splitters['columns'].setSizes([1, 1])
