@@ -6,10 +6,11 @@
 # GitHub:  https://github.com/szczyglis-dev/py-gpt   #
 # MIT License                                        #
 # Created By  : Marcin Szczygliński                  #
-# Updated Date: 2025.08.01 19:00:00                  #
+# Updated Date: 2025.08.05 21:00:00                  #
 # ================================================== #
 
 import time
+import weakref
 from datetime import datetime, timedelta
 from typing import Optional, Dict, Any
 
@@ -44,7 +45,7 @@ class Bridge:
         ]
         self.worker = None
 
-    async def request(
+    def request(
             self,
             context: BridgeContext,
             extra: Optional[Dict[str, Any]] = None
@@ -129,26 +130,26 @@ class Bridge:
                 self.window.core.debug.debug(str(debug))
 
         self.apply_rate_limit()  # apply RPM limit
-        self.last_context = context  # store last context for call (debug)
+        self.last_context = weakref.ref(context)  # store last context for call (debug)
 
         if extra is None:
             extra = {}
 
         # async worker
-        self.worker = self.get_worker()
-        self.worker.context = context
-        self.worker.extra = extra
-        self.worker.mode = mode
+        worker = self.get_worker()
+        worker.context = context
+        worker.extra = extra
+        worker.mode = mode
 
         # some modes must be called synchronously
         if mode in self.sync_modes or force_sync:
             self.window.core.debug.info("[bridge] Starting worker (sync)...")
-            self.worker.run()
+            worker.run()
             return True
 
         # async call
         self.window.core.debug.info("[bridge] Starting worker (async)...")
-        self.window.threadpool.start(self.worker)
+        self.window.threadpool.start(worker)
         return True
 
     def request_next(
@@ -169,13 +170,13 @@ class Bridge:
             extra = {}
 
         # async worker
-        self.worker = self.get_worker()
-        self.worker.context = context
-        self.worker.extra = extra
-        self.worker.mode = "loop_next"
+        worker = self.get_worker()
+        worker.context = context
+        worker.extra = extra
+        worker.mode = "loop_next"
 
         # async call
-        self.window.threadpool.start(self.worker)
+        self.window.threadpool.start(worker)
         return True
 
     def call(
@@ -200,7 +201,7 @@ class Bridge:
                 self.window.core.debug.debug(str(debug))
 
         # --- DEBUG ONLY ---
-        self.last_context_quick = context  # store last context for quick call (debug)
+        self.last_context_quick = weakref.ref(context)  # store last context for quick call (debug)
 
         if context.model is not None:
             # check if model is supported by OpenAI API, if not then try to use llama-index or langchain call
