@@ -6,7 +6,7 @@
 # GitHub:  https://github.com/szczyglis-dev/py-gpt   #
 # MIT License                                        #
 # Created By  : Marcin Szczygliński                  #
-# Updated Date: 2025.08.02 20:00:00                  #
+# Updated Date: 2025.08.09 20:00:00                  #
 # ================================================== #
 
 import copy
@@ -429,14 +429,17 @@ class Ctx:
         if meta is None:
             self.window.core.debug.log("Error creating new ctx")
             return
+        preset = self.window.core.config.get('preset')
+        meta.preset = preset
         self.meta[meta.id] = meta
         self.tmp_meta = meta
         self.current = meta.id
+        self.last_item = None
         self.thread = None
         self.assistant = None
         self.mode = self.window.core.config.get('mode')
         self.model = self.window.core.config.get('model')
-        self.preset = self.window.core.config.get('preset')
+        self.preset = preset
         self.clear_items()
         self.save(meta.id)
 
@@ -1415,6 +1418,18 @@ class Ctx:
             return None
         return self.groups[id]
 
+    def update_model_in_current(self, model):
+        """
+        Update model in current context
+
+        :param model: model name
+        """
+        if self.current is None:
+            return
+        if self.current in self.meta:
+            self.meta[self.current].last_model = model
+            self.save(self.current)
+
     def remove_group(
             self,
             group: CtxGroup,
