@@ -6,9 +6,10 @@
 # GitHub:  https://github.com/szczyglis-dev/py-gpt   #
 # MIT License                                        #
 # Created By  : Marcin Szczygliński                  #
-# Updated Date: 2025.07.24 01:00:00                  #
+# Updated Date: 2025.08.11 18:00:00                  #
 # ================================================== #
 
+import gc
 import os
 import sys
 import threading
@@ -19,9 +20,14 @@ import logging
 from pathlib import Path
 from typing import Any, Tuple
 
+import psutil
+from PySide6.QtWidgets import QApplication
+
 from pygpt_net.config import Config
 from pygpt_net.core.types.console import Color
 
+from .console import Console
+
 class Debug:
     def __init__(self, window=None):
         """
@@ -30,6 +36,7 @@ class Debug:
         :param window: Window instance
         """
         self.window = window
+        self.console = Console(window)
         self.pause_idx = 1
 
     @staticmethod
@@ -197,9 +204,10 @@ class Debug:
         try:
             # string message
             if isinstance(message, str):
-                logger.log(level, message)
-                if self.has_level(level) and console:
-                    print(message)
+                if self.has_level(level):
+                    logger.log(level, message)
+                    if console:
+                        print(message)
 
             # exception
             elif isinstance(message, Exception):
@@ -213,15 +221,16 @@ class Debug:
 
             # other messages
             else:
-                logger.log(level, message)
-                if self.has_level(level) and console:
-                    print(message)
+                if self.has_level(level):
+                    logger.log(level, message)
+                    if console:
+                        print(message)
         except Exception as e:
             pass
 
         try:
             # send to logger window
-            if self.window is not None:
+            if self.has_level(level) and self.window is not None:
                 # append thread ID
                 thread_suffix = ""
                 if not threading.current_thread() is threading.main_thread():
@@ -330,6 +339,78 @@ class Debug:
         """
         self.window.controller.dialogs.debug.add(id, k, v)
 
+    def print_memory_usage(self, label="") -> str:
+        """
+        Print memory usage of the current process
+
+        :param label: label for memory usage
+        :return: formatted memory usage string
+        """
+        process = psutil.Process(os.getpid())
+        mem_mb = process.memory_info().rss / (1024 * 1024)
+        data = f"Memory Usage: {mem_mb:.2f} MB"
+        print(f"[{label}] {data}")
+        return data
+
+    def mem(self, label: str = "") -> str:
+        """
+        Print memory usage and collect garbage
+
+        :param label: label for memory usage
+        :return: formatted memory usage string
+        """
+        res = ""
+        print("\n\n------------------------------------")
+        print(f"{Color.BOLD}{label} Memory Usage{Color.ENDC}")
+        print("------------------------------------")
+
+        all_objects = len(gc.get_objects())
+        unreachable_objects = gc.collect()
+
+        num_widgets = len(QApplication.allWidgets())
+        num_threads = self.window.threadpool.activeThreadCount()
+
+        stats = []
+        stats.append(f"[GC] All: {all_objects}, Unreachable: {unreachable_objects}")
+
+        res += self.print_memory_usage(label)
+
+        try:
+            from pympler import asizeof, summary, muppy  # pip install pympler
+            objs = muppy.get_objects()
+            # objs_by_type = muppy.filter(objs, Type=dict)
+            sum_by_type = summary.summarize(objs)
+            # sum_by_type = summary.summarize(objs_by_type)
+            summary.print_(sum_by_type)
+
+            total_bytes = asizeof.asizeof(self.window.controller.chat.render.web_renderer.pids)
+            pids_total_mb = total_bytes / (1024 * 1024)
+            count_pids = len(self.window.controller.chat.render.web_renderer.pids)
+
+            total_bytes = asizeof.asizeof(self.window.core.ctx.meta)
+            meta_total_mb = total_bytes / (1024 * 1024)
+            count_meta = len(self.window.core.ctx.meta)
+
+            total_bytes = asizeof.asizeof(self.window.core.ctx.get_items())
+            ctx_total_mb = total_bytes / (1024 * 1024)
+            count_ctx = len(self.window.core.ctx.get_items())
+
+            stats.append(f"Pids: {pids_total_mb:.4f} MB ({count_pids})")
+            stats.append(f"CtxMeta: {meta_total_mb:.4f} MB ({count_meta})")
+            stats.append(f"CtxItems: {ctx_total_mb:.4f} MB ({count_ctx})")
+
+        except ImportError:
+            err = "Pympler is not installed, skipping detailed memory report. Install it with 'pip install pympler'"
+            res += err
+            print(err)
+
+        stats.append(f"Widgets: {num_widgets}")
+        stats.append(f"Threadpool: {num_threads}")
+
+        res += "\n" + "\n".join(stats)
+        print("\n".join(stats))
+        return res
+
     def pause(self, *args):
         """
         Pause execution
