@@ -39,6 +39,14 @@ class BaseRenderer:
         """
         pass
 
+    def fresh(self, meta: CtxMeta):
+        """
+        Fresh renderer
+
+        :param meta: context PID
+        """
+        pass
+
     def get_pid(self, meta: CtxMeta):
         """
         Get PID for context meta
@@ -466,3 +474,9 @@ class BaseRenderer:
         :param ctx: context item
         """
         pass
+
+    def remove_pid(self, pid: int):
+        """
+        Remove PID from renderer
+        """
+        pass
