@@ -6,7 +6,7 @@
 # GitHub:  https://github.com/szczyglis-dev/py-gpt   #
 # MIT License                                        #
 # Created By  : Marcin Szczygliński                  #
-# Updated Date: 2025.07.26 18:00:00                  #
+# Updated Date: 2025.08.06 19:00:00                  #
 # ================================================== #
 
 import copy
@@ -16,6 +16,7 @@ import time
 
 
 class CtxItem:
+
     def __init__(self, mode=None):
         """
         Context item
@@ -214,11 +215,12 @@ class CtxItem:
     def get_pid(self):
         return 0
 
-    def to_dict(self, dump: bool = False) -> dict:
+    def to_dict(self, dump: bool = False, format: bool = False) -> dict:
         """
         Dump context item to dict
 
         :param dump: if True, dump meta to dict
+        :param format: if True, format output
         :return: dict
         """
         data = {
@@ -285,8 +287,17 @@ class CtxItem:
             data["sub_call"] = self.sub_call
             data["sub_reply"] = self.sub_reply
             data["sub_tool_call"] = self.sub_tool_call
+
         return data
 
+    def to_debug(self):
+        """
+        Dump context item to dict for debug
+
+        :return: dict
+        """
+        return json.dumps(self.to_dict(), ensure_ascii=False, indent=4)
+
     def from_dict(self, data: dict):
         """
         Load context item from dict
@@ -373,6 +384,7 @@ class CtxItem:
 
 
 class CtxMeta:
+
     def __init__(self, id=None):
         """
         Context meta data
@@ -564,6 +576,7 @@ class CtxMeta:
         return self.dump()
 
 class CtxGroup:
+
     def __init__(self, id=None, name=None):
         """
         Context group
