@@ -6,7 +6,7 @@
 # GitHub:  https://github.com/szczyglis-dev/py-gpt   #
 # MIT License                                        #
 # Created By  : Marcin Szczygliński                  #
-# Updated Date: 2025.08.01 19:00:00                  #
+# Updated Date: 2025.08.08 05:00:00                  #
 # ================================================== #
 
 from pygpt_net.core.events import KernelEvent
@@ -63,7 +63,7 @@ class Summarizer:
         )
         event = KernelEvent(KernelEvent.FORCE_CALL, {
             'context': bridge_context,
-            'extra': {},
+            'extra': {"disable_tools": True},
             'response': None,
         })
         self.window.dispatch(event)
