@@ -6,7 +6,7 @@
 # GitHub:  https://github.com/szczyglis-dev/py-gpt   #
 # MIT License                                        #
 # Created By  : Marcin Szczygliński                  #
-# Updated Date: 2025.07.26 18:00:00                  #
+# Updated Date: 2025.07.30 00:00:00                  #
 # ================================================== #
 
 import base64
@@ -107,7 +107,7 @@ class Vision:
         max_ctx_tokens = self.window.core.config.get('max_total_tokens')
 
         # fit to max model tokens
-        if max_ctx_tokens > model.ctx:
+        if max_ctx_tokens > model.ctx and model.ctx > 0:
             max_ctx_tokens = model.ctx
 
         # input tokens: reset
@@ -248,6 +248,65 @@ class Vision:
 
         return content
 
+    def build_agent_input(
+            self,
+            prompt: str,
+            attachments: Optional[Dict[str, AttachmentItem]] = None,
+    ) -> List[dict]:
+        """
+        Build agent input content
+
+        :param prompt: user prompt
+        :param attachments: attachments (dict, optional)
+        :return: List of contents
+        """
+        items = []
+        content = []
+        self.attachments = {}  # reset attachments, only current prompt
+        self.urls = []
+
+        # extract URLs from prompt
+        urls = self.extract_urls(prompt)
+        if len(urls) > 0:
+            for url in urls:
+                content.append(
+                    {
+                        "type": "input_image",
+                        "image_url": url,
+                    }
+                )
+                self.urls.append(url)
+
+        # local images (attachments)
+        if attachments is not None and len(attachments) > 0:
+            for id in attachments:
+                attachment = attachments[id]
+                if os.path.exists(attachment.path):
+                    # check if it's an image
+                    if self.is_image(attachment.path):
+                        base64_image = self.encode_image(attachment.path)
+                        content.append(
+                            {
+                                "type": "input_image",
+                                "detail": "auto",
+                                "image_url": f"data:image/jpeg;base64,{base64_image}",
+                            }
+                        )
+                        self.attachments[id] = attachment.path
+                        attachment.consumed = True
+
+        if content:
+            items.append({
+                "role": "user",
+                "content": content
+            })
+        items.append({
+            "role": "user",
+            "content": str(prompt)
+        })
+
+        return items
+
     def get_attachment(
             self,
             attachments: Optional[Dict[str, AttachmentItem]] = None,
