@@ -6,10 +6,10 @@
 # GitHub:  https://github.com/szczyglis-dev/py-gpt   #
 # MIT License                                        #
 # Created By  : Marcin Szczygliński                  #
-# Updated Date: 2024.12.14 22:00:00                  #
+# Updated Date: 2025.06.28 16:00:00                  #
 # ================================================== #
 
-from langchain_community.llms import HuggingFaceHub
+# from langchain_community.llms import HuggingFaceHub
 
 from pygpt_net.core.types import (
     MODE_LANGCHAIN,
@@ -22,7 +22,8 @@ class HuggingFaceLLM(BaseLLM):
     def __init__(self, *args, **kwargs):
         super(HuggingFaceLLM, self).__init__(*args, **kwargs)
         self.id = "huggingface"
-        self.type = [MODE_LANGCHAIN]
+        self.name = "HuggingFace"
+        self.type = []
 
     def completion(
             self,
@@ -37,9 +38,13 @@ class HuggingFaceLLM(BaseLLM):
         :param model: model instance
         :param stream: stream mode
         :return: LLM provider instance
-        """
+
         args = self.parse_args(model.langchain)
+        if "model" not in args:
+            args["model"] = model.id
         return HuggingFaceHub(**args)
+        """
+        pass
 
     def chat(
             self,
@@ -55,4 +60,4 @@ class HuggingFaceLLM(BaseLLM):
         :param stream: stream mode
         :return: LLM provider instance
         """
-        return None
+        pass
