@@ -6,7 +6,7 @@
 # GitHub:  https://github.com/szczyglis-dev/py-gpt   #
 # MIT License                                        #
 # Created By  : Marcin Szczygliński                  #
-# Updated Date: 2025.07.20 16:00:00                  #
+# Updated Date: 2025.08.05 21:00:00                  #
 # ================================================== #
 
 import json
@@ -19,7 +19,7 @@ from PySide6.QtGui import QTextCursor, QAction, QIcon
 from PySide6.QtWidgets import QWidget
 
 from pygpt_net.core.tabs.tab import Tab
-from pygpt_net.tools.base import BaseTool
+from pygpt_net.tools.base import BaseTool, TabWidget
 from pygpt_net.tools.code_interpreter.ui.dialogs import Tool
 from pygpt_net.core.events import Event, KernelEvent, BaseEvent, RenderEvent
 from pygpt_net.item.ctx import CtxItem
@@ -94,34 +94,46 @@ class CodeInterpreter(BaseTool):
 
     def set_initial_size(self):
         """Set default sizes"""
+        # --------------------------------------------------------
+        # INFO: object may be deleted before this method is called
+        # --------------------------------------------------------
         def set_initial_splitter_height():
-            total_height = self.window.ui.splitters['interpreter'].size().height()
-            if total_height > 0:
-                size_output = int(total_height * 0.85)
-                size_input = total_height - size_output
-                self.window.ui.splitters['interpreter'].setSizes([size_output, size_input])
-            else:
-                QTimer.singleShot(0, set_initial_splitter_height)
+            try:
+                total_height = self.window.ui.splitters['interpreter'].size().height()
+                if total_height > 0:
+                    size_output = int(total_height * 0.85)
+                    size_input = total_height - size_output
+                    self.window.ui.splitters['interpreter'].setSizes([size_output, size_input])
+                else:
+                    QTimer.singleShot(0, set_initial_splitter_height)
+            except Exception as e:
+                pass
         QTimer.singleShot(0, set_initial_splitter_height)
 
         def set_initial_splitter_dialog_height():
-            total_height = self.window.ui.splitters['interpreter_dialog'].size().height()
-            if total_height > 0:
-                size_output = int(total_height * 0.85)
-                size_input = total_height - size_output
-                self.window.ui.splitters['interpreter_dialog'].setSizes([size_output, size_input])
-            else:
-                QTimer.singleShot(0, set_initial_splitter_dialog_height)
+            try:
+                total_height = self.window.ui.splitters['interpreter_dialog'].size().height()
+                if total_height > 0:
+                    size_output = int(total_height * 0.85)
+                    size_input = total_height - size_output
+                    self.window.ui.splitters['interpreter_dialog'].setSizes([size_output, size_input])
+                else:
+                    QTimer.singleShot(0, set_initial_splitter_dialog_height)
+            except Exception as e:
+                pass
         QTimer.singleShot(0, set_initial_splitter_dialog_height)
 
         def set_initial_splitter_width():
-            total_width = self.window.ui.splitters['interpreter.columns'].size().width()
-            if total_width > 0:
-                size_output = int(total_width * 0.85)
-                size_history = total_width - size_output
-                self.window.ui.splitters['interpreter.columns'].setSizes([size_output, size_history])
-            else:
-                QTimer.singleShot(0, set_initial_splitter_width)
+            try:
+                total_width = self.window.ui.splitters['interpreter.columns'].size().width()
+                if total_width > 0:
+                    size_output = int(total_width * 0.85)
+                    size_history = total_width - size_output
+                    self.window.ui.splitters['interpreter.columns'].setSizes([size_output, size_history])
+                else:
+                    QTimer.singleShot(0, set_initial_splitter_width)
+            except Exception as e:
+                pass
         QTimer.singleShot(0, set_initial_splitter_width)
 
     def handle_ipython_output(self, line: str):
@@ -745,10 +757,10 @@ class CodeInterpreter(BaseTool):
         :return: Tab widget instance
         """
         tool = Tool(window=self.window, tool=self)  # dialog
-        tool.widget.set_is_dialog(False)
-        layout = tool.widget.setup(all=False)
-        widget = QWidget()
-        widget.setLayout(layout)
+        tool_widget = tool.as_tab()  # ToolWidget
+        widget = TabWidget()
+        widget.from_tool(tool_widget)
+        widget.setup()
         self.load_history()
         self.load_output()
         tool.set_tab(tab)
