@@ -6,7 +6,7 @@
 # GitHub:  https://github.com/szczyglis-dev/py-gpt   #
 # MIT License                                        #
 # Created By  : Marcin Szczygliński                  #
-# Updated Date: 2025.08.03 14:00:00                  #
+# Updated Date: 2025.08.11 00:00:00                  #
 # ================================================== #
 
 import copy
@@ -60,6 +60,7 @@ class MainWindow(QMainWindow, QtStyleTools):
         self.update_timer_interval = 300000  # check every 5 minutes
         self.state = self.STATE_IDLE
         self.prevState = None
+        self.is_post_update = False
 
         # load version info
         self.meta = get_app_meta()
@@ -228,9 +229,13 @@ class MainWindow(QMainWindow, QtStyleTools):
 
     def post_update(self):
         """Called on post-update (lazy)"""
+        if self.is_post_update:
+            return
+        self.is_post_update = True
         self.controller.debug.on_post_update()
         self.controller.plugins.on_post_update()
         self.tools.on_post_update()
+        self.is_post_update = False
 
     @Slot(str)
     def update_status(self, message: str = ""):
@@ -271,7 +276,17 @@ class MainWindow(QMainWindow, QtStyleTools):
             event.ignore()
             self.hide()
             return
+        self.shutdown()
+        event.accept()
 
+    def shutdown(self):
+        """
+        Shutdown the application gracefully
+        This method is called when the application is closing.
+        """
+        if self.is_closing:
+            print("Application is already closing.")
+            return
         self.is_closing = True
         print("Closing...")
         print("Sending terminate signal to all...")
@@ -301,7 +316,6 @@ class MainWindow(QMainWindow, QtStyleTools):
         print("Exiting...")
         print("")
         print("Have a nice day! :)")
-        event.accept()
 
     def changeEvent(self, event):
         """
