@@ -3,13 +3,14 @@
 # ================================================== #
 # This file is a part of PYGPT package               #
 # Website: https://pygpt.net                         #
-# GitHub:  https://github.com/szczyglis-dev/py-gpt   #
+# GitHub:  https://github.com/szczyglis-dev/py-gpt    #
 # MIT License                                        #
 # Created By  : Marcin Szczygliński                  #
 # Updated Date: 2025.07.20 23:00:00                  #
 # ================================================== #
 
 import datetime
+import functools
 
 from PySide6 import QtWidgets, QtCore, QtGui
 from PySide6.QtCore import Qt, QPoint, QItemSelectionModel
@@ -46,7 +47,6 @@ class ContextList(BaseList):
 
         :param index: index
         """
-        # only if left mouse button:
         item = self.window.ui.models['ctx.list'].itemFromIndex(index)
         if item is not None:
             if not hasattr(item, 'isFolder'):
@@ -120,41 +120,41 @@ class ContextList(BaseList):
                 and hasattr(item, 'id')):
 
             idx = item.row()
-            id = item.id
+            id_value = item.id
 
             # group context menu
             if hasattr(item, 'isFolder') and item.isFolder:
                 actions = {}
                 actions['new'] = QAction(QIcon(":/icons/add.svg"), trans('action.ctx.new'), self)
                 actions['new'].triggered.connect(
-                    lambda checked=False, id=id: self.window.controller.ctx.new(force=False, group_id=id)
+                    functools.partial(self.window.controller.ctx.new, force=False, group_id=id_value)
                 )
                 actions['rename'] = QAction(QIcon(":/icons/edit.svg"), trans('action.rename'), self)
                 actions['rename'].triggered.connect(
-                    lambda checked=False, id=id: self.window.controller.ctx.rename_group(id)
+                    functools.partial(self.window.controller.ctx.rename_group, id_value)
                 )
                 actions['delete'] = QAction(QIcon(":/icons/delete.svg"), trans('action.group.delete.only'), self)
                 actions['delete'].triggered.connect(
-                    lambda checked=False, id=id: self.window.controller.ctx.delete_group(id)
+                    functools.partial(self.window.controller.ctx.delete_group, id_value)
                 )
                 actions['delete_all'] = QAction(QIcon(":/icons/delete.svg"), trans('action.group.delete.all'), self)
                 actions['delete_all'].triggered.connect(
-                    lambda checked=False, id=id: self.window.controller.ctx.delete_group_all(id)
+                    functools.partial(self.window.controller.ctx.delete_group_all, id_value)
                 )
 
                 menu = QMenu(self)
                 menu.addAction(actions['new'])
                 menu.addAction(actions['rename'])
-                menu.addAction(actions['delete'])  # delete group
-                menu.addAction(actions['delete_all'])  # delete group and all contexts
+                menu.addAction(actions['delete'])
+                menu.addAction(actions['delete_all'])
 
                 if idx >= 0:
                     menu.exec_(global_pos)
 
             # children context menu
             else:
-                ctx_id = id
-                ctx = self.window.core.ctx.get_meta_by_id(id)
+                ctx_id = id_value
+                ctx = self.window.core.ctx.get_meta_by_id(ctx_id)
                 if ctx is None:
                     return
 
@@ -163,48 +163,48 @@ class ContextList(BaseList):
                 actions = {}
                 actions['open'] = QAction(QIcon(":/icons/chat.svg"), trans('action.open'), self)
                 actions['open'].triggered.connect(
-                    lambda checked=False, ctx_id=ctx_id: self.action_open(ctx_id, idx)
+                    functools.partial(self.action_open, ctx_id, idx)
                 )
 
                 actions['open_new_tab'] = QAction(QIcon(":/icons/chat.svg"), trans('action.open_new_tab'), self)
                 actions['open_new_tab'].triggered.connect(
-                    lambda checked=False, ctx_id=ctx_id: self.action_open_new_tab(ctx_id, idx)
+                    functools.partial(self.action_open_new_tab, ctx_id, idx)
                 )
 
                 actions['rename'] = QAction(QIcon(":/icons/edit.svg"), trans('action.rename'), self)
                 actions['rename'].triggered.connect(
-                    lambda checked=False, ctx_id=ctx_id: self.action_rename(ctx_id)
+                    functools.partial(self.action_rename, ctx_id)
                 )
 
                 if is_important:
                     actions['important'] = QAction(QIcon(":/icons/pin.svg"), trans('action.unpin'), self)
                     actions['important'].triggered.connect(
-                        lambda checked=False, ctx_id=ctx_id: self.action_unpin(ctx_id)
+                        functools.partial(self.action_unpin, ctx_id)
                     )
                 else:
                     actions['important'] = QAction(QIcon(":/icons/pin.svg"), trans('action.pin'), self)
                     actions['important'].triggered.connect(
-                        lambda checked=False, ctx_id=ctx_id: self.action_pin(ctx_id)
+                        functools.partial(self.action_pin, ctx_id)
                     )
 
                 actions['duplicate'] = QAction(QIcon(":/icons/copy.svg"), trans('action.duplicate'), self)
                 actions['duplicate'].triggered.connect(
-                    lambda checked=False, ctx_id=ctx_id: self.action_duplicate(ctx_id)
+                    functools.partial(self.action_duplicate, ctx_id)
                 )
 
                 actions['delete'] = QAction(QIcon(":/icons/delete.svg"), trans('action.delete'), self)
                 actions['delete'].triggered.connect(
-                    lambda checked=False, ctx_id=ctx_id: self.action_delete(ctx_id)
+                    functools.partial(self.action_delete, ctx_id)
                 )
 
-                actions['copy_id'] = QAction(QIcon(":/icons/copy.svg"), trans('action.ctx_copy_id') + " @" + str(id), self)
+                actions['copy_id'] = QAction(QIcon(":/icons/copy.svg"), trans('action.ctx_copy_id') + " @" + str(ctx_id), self)
                 actions['copy_id'].triggered.connect(
-                    lambda checked=False, ctx_id=ctx_id: self.action_copy_id(ctx_id)
+                    functools.partial(self.action_copy_id, ctx_id)
                 )
 
                 actions['reset'] = QAction(QIcon(":/icons/close.svg"), trans('action.ctx_reset'), self)
                 actions['reset'].triggered.connect(
-                    lambda checked=False, ctx_id=ctx_id: self.action_reset(ctx_id)
+                    functools.partial(self.action_reset, ctx_id)
                 )
 
                 menu = QMenu(self)
@@ -228,9 +228,7 @@ class ContextList(BaseList):
                     icon = QIcon(pixmap)
                     status_action = QAction(icon, name, self)
                     status_action.triggered.connect(
-                        lambda checked=False,
-                               ctx_id=ctx_id,
-                               s_id=status_id: self.window.controller.ctx.set_label(ctx_id, s_id)
+                        functools.partial(self.window.controller.ctx.set_label, ctx_id, status_id)
                     )
                     set_label_menu.addAction(status_action)
 
@@ -240,22 +238,17 @@ class ContextList(BaseList):
                 idxs = self.window.core.config.get('llama.idx.list')
                 store = self.window.core.idx.get_current_store()  # get current idx store provider
                 if len(idxs) > 0:
-                    for index in idxs:
-                        id = index['id']
-                        name = index['name'] + " (" + index['id'] + ")"
-
-                        # add to index
+                    for idx_dict in idxs:
+                        index_id = idx_dict['id']
+                        name = idx_dict['name'] + " (" + idx_dict['id'] + ")"
                         action = idx_menu.addAction("IDX: " + name)
                         action.setIcon(QIcon(":/icons/db.svg"))
                         action.triggered.connect(
-                            lambda checked=False,
-                                   ctx_id=ctx_id,
-                                   index=id: self.action_idx(ctx_id, index)
+                            functools.partial(self.action_idx, ctx_id, index_id)
                         )
 
                     # remove from index
                     if ctx.indexed is not None and ctx.indexed > 0:
-                        # get list of indexes in which context is indexed
                         if store in ctx.indexes:
                             store_indexes = ctx.indexes[store]
                             idx_menu.addSeparator()
@@ -263,14 +256,10 @@ class ContextList(BaseList):
                                 action = idx_menu.addAction(trans("action.idx.remove") + ": " + store_index)
                                 action.setIcon(QIcon(":/icons/delete.svg"))
                                 action.triggered.connect(
-                                    lambda checked=False,
-                                           store_index=store_index,
-                                           ctx_id=ctx_id: self.action_idx_remove(store_index, ctx_id)  # by context meta id
+                                    functools.partial(self.action_idx_remove, store_index, ctx_id)
                                 )
                     menu.addMenu(idx_menu)
 
-                # -----------------------------------------
-
                 # move to group menu
                 group_menu = QMenu(trans('action.move_to'), self)
                 groups = self.window.core.ctx.get_groups()
@@ -279,29 +268,22 @@ class ContextList(BaseList):
                 action = group_menu.addAction(trans("action.group.new"))
                 action.setIcon(QIcon(":/icons/add.svg"))
                 action.triggered.connect(
-                    lambda checked=False, ctx_id=ctx_id: self.window.controller.ctx.new_group(ctx_id)
+                    functools.partial(self.window.controller.ctx.new_group, ctx_id)
                 )
 
-                # add separator if groups exists
                 if len(groups) > 0:
                     group_menu.addSeparator()
 
-                # list of groups
-                for group_id in groups:
-                    group = groups[group_id]
+                for group_id, group in groups.items():
                     action = group_menu.addAction(group.name)
                     action.setIcon(QIcon(":/icons/folder_filled.svg"))
                     action.triggered.connect(
-                        lambda checked=False,
-                               group_id=group_id,
-                               ctx_id=ctx_id: self.window.controller.ctx.move_to_group(ctx_id, group_id)
+                        functools.partial(self.window.controller.ctx.move_to_group, ctx_id, group_id)
                     )
 
-                # add separator if groups exists
                 if len(groups) > 0:
                     group_menu.addSeparator()
 
-                # if in group add remove from group
                 if ctx.group_id is not None and ctx.group_id > 0:
                     group_name = str(ctx.group_id)
                     if ctx.group_id in groups:
@@ -309,16 +291,13 @@ class ContextList(BaseList):
                     action = group_menu.addAction(trans("action.group.remove") + ": " + group_name)
                     action.setIcon(QIcon(":/icons/delete.svg"))
                     action.triggered.connect(
-                        lambda checked=False,
-                               ctx_id=ctx_id: self.window.controller.ctx.remove_from_group(ctx_id)
+                        functools.partial(self.window.controller.ctx.remove_from_group, ctx_id)
                     )
 
                 menu.addMenu(group_menu)
 
                 menu.addAction(actions['copy_id'])
 
-                # -----------------------------------------
-
                 # show last indexed date if available
                 if ctx.indexed is not None and ctx.indexed > 0:
                     suffix = ""
@@ -326,7 +305,7 @@ class ContextList(BaseList):
                         suffix = " *"
                     dt = datetime.datetime.fromtimestamp(ctx.indexed).strftime("%Y-%m-%d %H:%M")
                     action = QAction(QIcon(":/icons/clock.svg"), trans('action.ctx.indexed') + ": " + dt + suffix, self)
-                    action.setEnabled(False)  # disable action, only for info
+                    action.setEnabled(False)
                     menu.addAction(action)
 
                 menu.addAction(actions['reset'])
@@ -335,20 +314,17 @@ class ContextList(BaseList):
                     self.window.controller.ctx.set_selected(ctx_id)
                     menu.exec_(global_pos)
 
-        # store previous scroll position
         self.store_scroll_position()
 
-        # restore selection if it was backed up
         if self.restore_after_ctx_menu:
             if self._backup_selection is not None:
                 self.selectionModel().clearSelection()
-                for idx in self._backup_selection:
+                for sel_idx in self._backup_selection:
                     self.selectionModel().select(
-                        idx, QItemSelectionModel.Select | QItemSelectionModel.Rows
+                        sel_idx, QItemSelectionModel.Select | QItemSelectionModel.Rows
                     )
                 self._backup_selection = None
 
-        # restore scroll position
         self.restore_after_ctx_menu = True
         self.restore_scroll_position()
 
@@ -359,17 +335,17 @@ class ContextList(BaseList):
         :param id: context id
         :param idx: index id (optional)
         """
-        self.restore_after_ctx_menu = False  # do not restore selection after context menu
+        self.restore_after_ctx_menu = False
         self.window.controller.ctx.load(id, select_idx=idx)
 
     def action_open_new_tab(self, id: int, idx: int = None):
         """
-        Open context action handler
+        Open context action handler in nowej karcie
 
         :param id: context id
-         :param idx: index id (optional)
+        :param idx: index id (optional)
         """
-        self.restore_after_ctx_menu = False  # do not restore selection after context menu
+        self.restore_after_ctx_menu = False
         self.window.controller.ctx.load(id, select_idx=idx, new_tab=True)
 
     def action_idx(self, id: int, idx: int):
@@ -379,7 +355,7 @@ class ContextList(BaseList):
         :param id: context id
         :param idx: index name
         """
-        self.restore_after_ctx_menu = False  # do not restore selection after context menu
+        self.restore_after_ctx_menu = False
         self.window.controller.idx.indexer.index_ctx_meta(id, idx)
 
     def action_idx_remove(self, idx: str, meta_id: int):
@@ -389,7 +365,7 @@ class ContextList(BaseList):
         :param idx: index id
         :param meta_id: meta id
         """
-        self.restore_after_ctx_menu = False  # do not restore selection after context menu
+        self.restore_after_ctx_menu = False
         self.window.controller.idx.indexer.index_ctx_meta_remove(idx, meta_id)
 
     def action_rename(self, id):
@@ -398,7 +374,7 @@ class ContextList(BaseList):
 
         :param id: context id
         """
-        self.restore_after_ctx_menu = False  # do not restore selection after context menu
+        self.restore_after_ctx_menu = False
         self.window.controller.ctx.rename(id)
 
     def action_pin(self, id):
@@ -407,7 +383,7 @@ class ContextList(BaseList):
 
         :param id: context id
         """
-        self.restore_after_ctx_menu = False  # do not restore selection after context menu
+        self.restore_after_ctx_menu = False
         self.window.controller.ctx.set_important(id, True)
 
     def action_unpin(self, id):
@@ -416,7 +392,7 @@ class ContextList(BaseList):
 
         :param id: context id
         """
-        self.restore_after_ctx_menu = False  # do not restore selection after context menu
+        self.restore_after_ctx_menu = False
         self.window.controller.ctx.set_important(id, False)
 
     def action_important(self, id):
@@ -425,12 +401,12 @@ class ContextList(BaseList):
 
         :param id: context id
         """
-        self.restore_after_ctx_menu = False  # do not restore selection after context menu
+        self.restore_after_ctx_menu = False
         self.window.controller.ctx.set_important(id)
 
     def action_duplicate(self, id):
         """
-        Rename duplicate handler
+        Duplicate handler
 
         :param id: context id
         """
@@ -442,7 +418,7 @@ class ContextList(BaseList):
 
         :param id: context id
         """
-        self.restore_after_ctx_menu = False  # do not restore selection after context menu
+        self.restore_after_ctx_menu = False
         self.window.controller.ctx.delete(id)
 
     def action_copy_id(self, id):
@@ -459,10 +435,9 @@ class ContextList(BaseList):
 
         :param id: context id
         """
-        self.restore_after_ctx_menu = False  # do not restore selection after context menu
+        self.restore_after_ctx_menu = False
         self.window.controller.ctx.common.reset(id)
 
-
     def selectionCommand(self, index, event=None):
         """
         Selection command
@@ -475,8 +450,6 @@ class ContextList(BaseList):
 class ImportantItemDelegate(QtWidgets.QStyledItemDelegate):
     """
     Label color delegate
-
-    :param QtWidgets.QStyledItemDelegate: parent class
     """
     def paint(self, painter, option, index):
         if index.parent().isValid():
@@ -484,25 +457,11 @@ class ImportantItemDelegate(QtWidgets.QStyledItemDelegate):
 
         super(ImportantItemDelegate, self).paint(painter, option, index)
 
-        # pin (>= 10)
         if index.data(QtCore.Qt.ItemDataRole.UserRole):
             data = index.data(QtCore.Qt.ItemDataRole.UserRole)
-            label = 0
-            is_important = False
-            is_attachment = False
-            is_group = False
-            in_group = False
-
-            if "label" in data:
-                label = data["label"]
-            if "is_important" in data and data["is_important"]:
-                is_important = True
-            if "is_attachment" in data and data["is_attachment"]:
-                is_attachment = True
-            if "is_group" in data and data["is_group"]:
-                is_group = True
-            if "in_group" in data and data["in_group"]:
-                in_group = True
+            label = data.get("label", 0)
+            is_important = data.get("is_important", False)
+            is_attachment = data.get("is_attachment", False)
 
             painter.save()
 
@@ -538,7 +497,6 @@ class ImportantItemDelegate(QtWidgets.QStyledItemDelegate):
                 )
                 painter.drawRect(square_rect)
 
-            # label (0-9)
             if label > 0:
                 color = self.get_color_for_status(label)
                 square_size = 5
@@ -556,12 +514,6 @@ class ImportantItemDelegate(QtWidgets.QStyledItemDelegate):
             painter.restore()
 
     def get_color_for_status(self, status: int) -> QColor:
-        """
-        Get color for status
-
-        :param status: status id
-        :return: color
-        """
         statuses = {
             0: {'label': 'label.color.default', 'color': QColor(100, 100, 100)},
             1: {'label': 'label.color.red', 'color': QColor(255, 0, 0)},
@@ -572,10 +524,8 @@ class ImportantItemDelegate(QtWidgets.QStyledItemDelegate):
             6: {'label': 'label.color.indigo', 'color': QColor(75, 0, 130)},
             7: {'label': 'label.color.violet', 'color': QColor(238, 130, 238)},
         }
-        if status in statuses:
-            return statuses[status]['color']
-        else:
-            return statuses[0]['color']
+        return statuses.get(status, statuses[0])['color']
+
 
 class GroupItem(QStandardItem):
     def __init__(self, icon, name, id):
@@ -587,6 +537,7 @@ class GroupItem(QStandardItem):
         self.hasAttachments = False
         self.dt = None
 
+
 class Item(QStandardItem):
     def __init__(self, name, id):
         super().__init__(name)
@@ -596,6 +547,7 @@ class Item(QStandardItem):
         self.isPinned = False
         self.dt = None
 
+
 class SectionItem(QStandardItem):
     def __init__(self, title, group: bool = False):
         super().__init__(title)
@@ -603,10 +555,7 @@ class SectionItem(QStandardItem):
         self.group = group
         self.setSelectable(False)
         self.setEnabled(False)
-        if self.group:
-            self.setTextAlignment(QtCore.Qt.AlignRight)
-        else:
-            self.setTextAlignment(QtCore.Qt.AlignRight)
+        self.setTextAlignment(QtCore.Qt.AlignRight)
         font = self.font()
         font.setBold(True)
-        self.setFont(font)
+        self.setFont(font)
\ No newline at end of file
